Commit 910c1cd0a0ce4a8ac55a089415bd065043223844

David Ludwig 2013-12-26T14:21:47

WinRT: minor error cleanup regarding OpenGL init

1
2
3
4
5
6
7
8
9
10
11
12
13
14
15
diff --git a/src/video/winrt/SDL_winrtvideo.cpp b/src/video/winrt/SDL_winrtvideo.cpp
index 900767f..ba1fd2f 100644
--- a/src/video/winrt/SDL_winrtvideo.cpp
+++ b/src/video/winrt/SDL_winrtvideo.cpp
@@ -288,8 +288,8 @@ WINRT_CreateWindow(_THIS, SDL_Window * window)
             _this->egl_data->egl_config,
             nativeWindow, NULL);
         if (data->egl_surface == NULL) {
-            // TODO, WinRT: see if SDL_EGL_CreateSurface, or its callee(s), sets an error message.  If so, attach it to the SDL error.
-            return SDL_SetError("SDL_EGL_CreateSurface failed");
+            // TODO, WinRT: see if eglCreateWindowSurface, or its callee(s), sets an error message.  If so, attach it to the SDL error.
+            return SDL_SetError("eglCreateWindowSurface failed");
         }
     }
 #endif